@@ -182,15 +182,6 @@ resources_update_operations = [
          "attributes": {"controller": {"type": "string", "min_length": 0,
                                        "max_length": 255, "required": True}}
      }]},
-    {"desc": "add switch_table resource type",
-     "type": "create_resource_type",
-     "resource_type": "switch_table",
-     "data": [{
-         "attributes": {"switch": {"type": "string", "min_length": 0,
-                                   "max_length": 64, "required": True},
-                        "controller": {"type": "string", "min_length": 0,
-                                       "max_length": 255, "required": True}}
-     }]},
     {"desc": "add volume provider resource type",
      "type": "create_resource_type",
      "resource_type": "volume_provider",
@@ -240,12 +231,6 @@ resources_update_operations = [
          "value": {"type": "string", "min_length": 0, "max_length": 255,
                    "required": False}
      }]},
-    {"desc": "add loadbalancer resource type",
-     "type": "create_resource_type",
-     "resource_type": "loadbalancer",
-     "data": [{
-         "attributes": {}
-     }]},
 ]
 
 # NOTE(sileht): We use LooseVersion because pbr can generate invalid
@@ -258,8 +243,8 @@ def upgrade_resource_types(conf):
 
     gnocchi_version = version.LooseVersion(gnocchi.build.get())
     if gnocchi_version < REQUIRED_VERSION:
-        raise Exception("required gnocchi version is %s, got %s",
-                        REQUIRED_VERSION, gnocchi_version)
+        raise Exception("required gnocchi version is %s, got %s" %
+                        (REQUIRED_VERSION, gnocchi_version))
 
     for name, attributes in resources_initial.items():
         try:
